@@ -1,16 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""Univariate regression example model.
-
-Correct parameter value is 5.0 (regression parameter).
-"""
+"""Univariate regression example model."""
 import pandas as pd
 import os
 
 __desc = 'y ~ x'
 
 __folder = os.path.dirname(os.path.abspath(__file__))
-__filename = '%s/univariate_data.csv' % __folder
+__filename = '%s/univariate_regression_data.csv' % __folder
+__filename_p = '%s/univariate_regression_params.csv' % __folder
 
 
 def get_model():
@@ -37,3 +35,15 @@ def get_data():
 
     """
     return pd.read_csv(__filename, index_col=0)
+
+def get_params():
+    """
+    Retrieve true parameter estimates.
+
+    Returns
+    -------
+    pd.DataFrame
+        Dataset.
+
+    """
+    return pd.read_csv(__filename_p, index_col=0)
\ No newline at end of file
